@@ -1,8 +1,8 @@
 from StructNoSQL.dynamodb.dynamodb_core import PrimaryIndex, GlobalSecondaryIndex
-from StructNoSQL.fields import BaseField, MapModel, MapField, TableDataModel
+from StructNoSQL.fields import BaseField, MapModel, TableDataModel
 from StructNoSQL.tables.base_table import BaseTable
 from StructNoSQL.tables.basic_table import BasicTable
 from StructNoSQL.tables.caching_table import CachingTable
-from StructNoSQL.validator import NoneType, ActiveSelf
+from StructNoSQL.validator import NoneType, Undefined, ActiveSelf
 from StructNoSQL.dynamodb.models import FieldGetter, FieldSetter, UnsafeFieldSetter, FieldRemover
 from StructNoSQL.exceptions import *
